---
title: "Interface"
---

This section of the documentation focuses on how the interface is
implemented. It is split into the following set of documents:

-   The [Inputs](inputs.qmd#inputs) accepted by Sprout, specifically the
    object types used to represent paths, properties, and data.
-   The main [Outputs](outputs.qmd#outputs), including the files,
    folders, and Python objects produced by Sprout.
-   The [Python functions](functions.qmd#functions) that form the core
    of Sprout and its extensions.
-   The [flow](flows.qmd#flows) of functions and objects visually
    represented in diagrams.
